@@ -1,7 +1,7 @@
 <?php
 /*
 
-@version V5.15 19 Jan 2012   (c) 2000-2012 John Lim (jlim#natsoft.com). All rights reserved.
+@version V5.18 3 Sep 2012   (c) 2000-2012 John Lim (jlim#natsoft.com). All rights reserved.
   Latest version is available at http://adodb.sourceforge.net
  
   Released under both BSD license and Lesser GPL library license. 
@@ -695,7 +695,7 @@ class ADODB_Active_Record {
 		if($where) {
 			$qry .= ' WHERE '.$where;
 		}
-		if ($locked) $qry .= $this->lockMode;
+		if ($lock) $qry .= $this->lockMode;
 		
 		$row = $db->GetRow($qry,$bindarr);
 		
